import type { AppProps } from 'next/app';
import type { ElementType, ReactNode } from 'react';
import type { Ni18nOptions } from '../common';
/**
 * Use `appWithI18Next` inside your `_app.jsx` file to initialize the `I18nextProvider`.
 *
 * ```jsx
 * const MyApp = ({ Component, pageProps }) => <Component {...pageProps} />
 *
 * export default appWithI18Next(MyApp, ni18nConfig)
 * ```
 *
 * @param WrappedComponent The MyApp component
 * @param options The options allowed by [i18next options](https://www.i18next.com/overview/configuration-options) plus the `use` property for plugins
 */
export declare const appWithI18Next: (WrappedComponent: ElementType<AppProps & {
    children?: ReactNode;
}>, options: Ni18nOptions) => ElementType;
